@@ -6,8 +6,8 @@
 ;; Author: Joost Kremers <joostkremers@fastmail.fm>
 ;; Maintainer: Joost Kremers <joostkremers@fastmail.fm>
 ;; Created: 2014
-;; Package-Version: 20250922.1100
-;; Package-Revision: 4a9df6f1b4f3
+;; Package-Version: 20251125.1320
+;; Package-Revision: b3990a189842
 ;; Keywords: text bibtex
 ;; URL: https://github.com/joostkremers/parsebib
 ;; Package-Requires: ((emacs "25.1"))
@@ -284,18 +284,18 @@ sequences)."
   (parsebib--skip-whitespace)
   (let ((beg (point))
         (n-braces 1)
-        (skip-chars (format "^%c%c" open close)))
+        (skip-chars (format "^%c%c%c" open close esc)))
     (parsebib--char (list open))
     (while (and (> n-braces 0)
                 (not (eobp)))
       (skip-chars-forward skip-chars)
       (cond
+       ((eq (char-after) esc)
+        (forward-char 1))
        ((eq (char-after) open)
-        (unless (eq (char-before) esc)
-          (setq n-braces (1+ n-braces))))
+        (setq n-braces (1+ n-braces)))
        ((eq (char-after) close)
-        (unless (eq (char-before) esc)
-          (setq n-braces (1- n-braces)))))
+        (setq n-braces (1- n-braces))))
       (ignore-error end-of-buffer (forward-char 1)))
     (if (= n-braces 0)
         (buffer-substring-no-properties beg (point))
@@ -1046,6 +1046,10 @@ FIELDS is nil, all fields are returned."
 This function looks for a local value of the variable
 `bibtex-dialect' in the local variable block at the end of the
 file.  Return nil if no dialect is found."
+  ;; We only want to find the value of `bibtex-dialect'; we don't want to
+  ;; set the variable, nor do we want to set any other file-local
+  ;; variables, and we also don't want to activate `bibtex-mode'.  All of
+  ;; this means that `hack-local-variables' is a non-starter.
   (save-excursion
     (goto-char (point-max))
     (let ((case-fold-search t)
